summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--res/values-ca/cm_arrays.xml27
-rw-r--r--res/values-ca/cm_plurals.xml27
-rw-r--r--res/values-ca/cm_strings.xml28
-rw-r--r--res/values-cs/cm_strings.xml31
-rw-r--r--res/values-da/cm_arrays.xml27
-rw-r--r--res/values-da/cm_plurals.xml29
-rw-r--r--res/values-da/cm_strings.xml33
-rw-r--r--res/values-de/cm_arrays.xml27
-rw-r--r--res/values-de/cm_plurals.xml27
-rw-r--r--res/values-de/cm_strings.xml27
-rw-r--r--res/values-el/cm_arrays.xml3
-rw-r--r--res/values-el/cm_plurals.xml3
-rw-r--r--res/values-el/cm_strings.xml3
-rw-r--r--res/values-es/cm_arrays.xml27
-rw-r--r--res/values-es/cm_plurals.xml27
-rw-r--r--res/values-es/cm_strings.xml27
-rw-r--r--res/values-fi/cm_plurals.xml27
-rw-r--r--res/values-fi/cm_strings.xml28
-rw-r--r--res/values-fr/cm_arrays.xml28
-rw-r--r--res/values-fr/cm_plurals.xml28
-rw-r--r--res/values-fr/cm_strings.xml28
-rw-r--r--res/values-hu/cm_arrays.xml27
-rw-r--r--res/values-hu/cm_plurals.xml27
-rw-r--r--res/values-hu/cm_strings.xml28
-rw-r--r--res/values-it/cm_arrays.xml27
-rw-r--r--res/values-it/cm_plurals.xml27
-rw-r--r--res/values-it/cm_strings.xml27
-rw-r--r--res/values-nl/cm_arrays.xml28
-rw-r--r--res/values-nl/cm_plurals.xml28
-rw-r--r--res/values-nl/cm_strings.xml30
-rw-r--r--res/values-pl/cm_arrays.xml28
-rw-r--r--res/values-pl/cm_plurals.xml27
-rw-r--r--res/values-pl/cm_strings.xml27
-rw-r--r--res/values-pt/cm_plurals.xml28
-rw-r--r--res/values-pt/cm_strings.xml15
-rw-r--r--res/values-ru/cm_arrays.xml27
-rw-r--r--res/values-ru/cm_plurals.xml27
-rw-r--r--res/values-ru/cm_strings.xml27
-rw-r--r--res/values-sk/cm_plurals.xml28
-rw-r--r--res/values-sk/cm_strings.xml27
-rw-r--r--res/values-sv/cm_plurals.xml28
-rw-r--r--res/values-sv/cm_strings.xml28
-rw-r--r--res/values-zh-rCN/cm_strings.xml49
-rw-r--r--res/values/cm_arrays.xml27
-rw-r--r--res/values/cm_plurals.xml27
-rw-r--r--res/values/cm_strings.xml27
-rw-r--r--src/com/android/dialer/calllog/CallLogFragment.java5
-rw-r--r--src/com/android/dialer/dialpad/DialpadFragment.java11
48 files changed, 633 insertions, 591 deletions
diff --git a/res/values-ca/cm_arrays.xml b/res/values-ca/cm_arrays.xml
new file mode 100644
index 000000000..4fd67ce98
--- /dev/null
+++ b/res/values-ca/cm_arrays.xml
@@ -0,0 +1,27 @@
+<?xml version="1.0" encoding="utf-8"?>
+<!--
+ Copyright (C) 2013 The CyanogenMod Project
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
+<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
+ <string-array name="call_stats_duration">
+ <item><xliff:g id="seconds" example="2 secs">%3$s</xliff:g></item>
+ <item><xliff:g id="minutes" example="2 mins">%2$s</xliff:g></item>
+ <item><xliff:g id="minutes" example="2 mins">%2$s</xliff:g> <xliff:g id="seconds" example="2 secs">%3$s</xliff:g></item>
+ <item><xliff:g id="hours" example="2 hrs">%1$s</xliff:g></item>
+ <item><xliff:g id="hours" example="2 hrs">%1$s</xliff:g> <xliff:g id="seconds" example="2 secs">%3$s</xliff:g></item>
+ <item><xliff:g id="hours" example="2 hrs">%1$s</xliff:g> <xliff:g id="minutes" example="2 mins">%2$s</xliff:g></item>
+ <item><xliff:g id="hours" example="2 hrs">%1$s</xliff:g> <xliff:g id="minutes" example="2 mins">%2$s</xliff:g> <xliff:g id="seconds" example="2 secs">%3$s</xliff:g></item>
+ </string-array>
+</resources>
diff --git a/res/values-ca/cm_plurals.xml b/res/values-ca/cm_plurals.xml
index ff957465a..ad2d8bd16 100644
--- a/res/values-ca/cm_plurals.xml
+++ b/res/values-ca/cm_plurals.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<plurals name="hour">
<item quantity="one">1 hr</item>
diff --git a/res/values-ca/cm_strings.xml b/res/values-ca/cm_strings.xml
index faf1c01b0..250a3682e 100644
--- a/res/values-ca/cm_strings.xml
+++ b/res/values-ca/cm_strings.xml
@@ -1,22 +1,20 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
-<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
+<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string name="callStatsDetailTitle">Detalls de les trucades</string>
<string name="call_stats">Estadístiques de trucades</string>
<string name="call_stats_refresh">Refresca</string>
diff --git a/res/values-cs/cm_strings.xml b/res/values-cs/cm_strings.xml
index 24d75fc32..2c3769597 100644
--- a/res/values-cs/cm_strings.xml
+++ b/res/values-cs/cm_strings.xml
@@ -1,26 +1,24 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string name="callStatsDetailTitle">Detaily volání</string>
<string name="call_stats">Statistiky hovoru</string>
<string name="call_stats_refresh">Obnovit</string>
<string name="activity_title_call_stats">Statistiky hovoru</string>
-
<string name="call_stats_nav_all">Vše</string>
<string name="call_stats_nav_incoming">Příschozí</string>
<string name="call_stats_nav_outgoing">Odchozí</string>
@@ -34,7 +32,6 @@
<string name="call_stats_filter_from">Datum zahájení</string>
<string name="call_stats_filter_to">Datum ukončení</string>
<string name="call_stats_filter_picker_title">Rozsah hodnot filtru</string>
-
<string name="date_quick_selection">Rychlý výběr</string>
<string name="date_qs_currentmonth">Aktuální měsíc</string>
<string name="date_qs_currentquarter">Aktuální čtvrtletí</string>
@@ -43,12 +40,10 @@
<string name="date_qs_lastmonth">Poslední měsíc</string>
<string name="date_qs_lastquarter">Poslední čtvrtletí</string>
<string name="date_qs_lastyear">Poslední rok</string>
-
<string name="call_stats_date_filter">Změnit časový rozsah</string>
<string name="call_stats_reset_filter">Obnovit časový rozsah</string>
<string name="call_stats_sort_by_duration">Řadit podle délky hovoru</string>
<string name="call_stats_sort_by_count">Řadit podle počtu hovorů</string>
-
<string name="menu_add_to_blacklist">Přidat na černou listinu</string>
<string name="toast_added_to_blacklist">%s bylo přidáno na černou listinu.</string>
</resources>
diff --git a/res/values-da/cm_arrays.xml b/res/values-da/cm_arrays.xml
index c07f9204a..4fd67ce98 100644
--- a/res/values-da/cm_arrays.xml
+++ b/res/values-da/cm_arrays.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string-array name="call_stats_duration">
<item><xliff:g id="seconds" example="2 secs">%3$s</xliff:g></item>
diff --git a/res/values-da/cm_plurals.xml b/res/values-da/cm_plurals.xml
index 66e30d54d..0f489c584 100644
--- a/res/values-da/cm_plurals.xml
+++ b/res/values-da/cm_plurals.xml
@@ -1,19 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<plurals name="hour">
<item quantity="one">1 time</item>
@@ -27,7 +27,6 @@
<item quantity="one">1 sekund</item>
<item quantity="other">%d sekunder</item>
</plurals>
-
<plurals name="call">
<item quantity="one">1 opkald</item>
<item quantity="other">%d opkald</item>
diff --git a/res/values-da/cm_strings.xml b/res/values-da/cm_strings.xml
index a5f20a58c..75114d4f4 100644
--- a/res/values-da/cm_strings.xml
+++ b/res/values-da/cm_strings.xml
@@ -1,28 +1,24 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
-<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
- <!-- Title bar for call stat detail screen -->
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
+<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string name="callStatsDetailTitle">Detaljer vedr. opkaldsstatistik</string>
<string name="call_stats">Opkaldsstatistik</string>
<string name="call_stats_refresh">Opdatér</string>
<string name="activity_title_call_stats">Opkaldsstatistik</string>
-
<string name="call_stats_nav_all">Alle</string>
<string name="call_stats_nav_incoming">Indgående</string>
<string name="call_stats_nav_outgoing">Udgående</string>
@@ -36,7 +32,6 @@
<string name="call_stats_filter_from">Startdato</string>
<string name="call_stats_filter_to">Slutdato</string>
<string name="call_stats_filter_picker_title">Datointerval</string>
-
<string name="date_quick_selection">Hurtigvalg</string>
<string name="date_qs_currentmonth">Aktuel måned</string>
<string name="date_qs_currentquarter">Aktuelt kvartal</string>
@@ -45,12 +40,10 @@
<string name="date_qs_lastmonth">Sidste måned</string>
<string name="date_qs_lastquarter">Sidste kvartal</string>
<string name="date_qs_lastyear">Sidste år</string>
-
<string name="call_stats_date_filter">Justér datointerval</string>
<string name="call_stats_reset_filter">Nulstil datointerval</string>
<string name="call_stats_sort_by_duration">Sortér efter opkaldslængde</string>
<string name="call_stats_sort_by_count">Sortér efter antal opkald</string>
-
<string name="menu_add_to_blacklist">Føj til sortliste</string>
<string name="toast_added_to_blacklist">%s føjet til sortliste.</string>
</resources>
diff --git a/res/values-de/cm_arrays.xml b/res/values-de/cm_arrays.xml
index f34b4df32..1632e6d38 100644
--- a/res/values-de/cm_arrays.xml
+++ b/res/values-de/cm_arrays.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string-array name="call_stats_duration">
<item><xliff:g id="seconds" example="2 secs">%3$s</xliff:g></item>
diff --git a/res/values-de/cm_plurals.xml b/res/values-de/cm_plurals.xml
index 3efd9c917..493bf3268 100644
--- a/res/values-de/cm_plurals.xml
+++ b/res/values-de/cm_plurals.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<plurals name="call">
<item quantity="one">1 Anruf</item>
diff --git a/res/values-de/cm_strings.xml b/res/values-de/cm_strings.xml
index 1b2cc87e7..e2a7eafdb 100644
--- a/res/values-de/cm_strings.xml
+++ b/res/values-de/cm_strings.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string name="callStatsDetailTitle">Anrufstatistikdetails</string>
<string name="call_stats">Anrufstatistik</string>
diff --git a/res/values-el/cm_arrays.xml b/res/values-el/cm_arrays.xml
index 30392a553..bc988c46a 100644
--- a/res/values-el/cm_arrays.xml
+++ b/res/values-el/cm_arrays.xml
@@ -1,5 +1,6 @@
<?xml version="1.0" encoding="utf-8"?>
-<!-- Copyright (C) 2013 The CyanogenMod Project
+<!--
+ Copyright (C) 2013 The CyanogenMod Project
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
diff --git a/res/values-el/cm_plurals.xml b/res/values-el/cm_plurals.xml
index 6498ad7ff..c48c34868 100644
--- a/res/values-el/cm_plurals.xml
+++ b/res/values-el/cm_plurals.xml
@@ -1,5 +1,6 @@
<?xml version="1.0" encoding="utf-8"?>
-<!-- Copyright (C) 2013 The CyanogenMod Project
+<!--
+ Copyright (C) 2013 The CyanogenMod Project
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
diff --git a/res/values-el/cm_strings.xml b/res/values-el/cm_strings.xml
index b4f9f25a7..73554705e 100644
--- a/res/values-el/cm_strings.xml
+++ b/res/values-el/cm_strings.xml
@@ -1,5 +1,6 @@
<?xml version="1.0" encoding="utf-8"?>
-<!-- Copyright (C) 2012-2013 The CyanogenMod Project
+<!--
+ Copyright (C) 2013 The CyanogenMod Project
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
diff --git a/res/values-es/cm_arrays.xml b/res/values-es/cm_arrays.xml
index f34b4df32..1632e6d38 100644
--- a/res/values-es/cm_arrays.xml
+++ b/res/values-es/cm_arrays.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string-array name="call_stats_duration">
<item><xliff:g id="seconds" example="2 secs">%3$s</xliff:g></item>
diff --git a/res/values-es/cm_plurals.xml b/res/values-es/cm_plurals.xml
index aced80225..e50065956 100644
--- a/res/values-es/cm_plurals.xml
+++ b/res/values-es/cm_plurals.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<plurals name="hour">
<item quantity="one">1 hora</item>
diff --git a/res/values-es/cm_strings.xml b/res/values-es/cm_strings.xml
index e5011b62d..b42c12f51 100644
--- a/res/values-es/cm_strings.xml
+++ b/res/values-es/cm_strings.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string name="menu_add_to_blacklist">Añadir a la lista negra</string>
<string name="toast_added_to_blacklist">%s añadido a la lista negra.</string>
diff --git a/res/values-fi/cm_plurals.xml b/res/values-fi/cm_plurals.xml
index 9894a7e3e..576b3b90b 100644
--- a/res/values-fi/cm_plurals.xml
+++ b/res/values-fi/cm_plurals.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<plurals name="hour">
<item quantity="one">1 h</item>
diff --git a/res/values-fi/cm_strings.xml b/res/values-fi/cm_strings.xml
index 2e3d74c74..8d8ccec48 100644
--- a/res/values-fi/cm_strings.xml
+++ b/res/values-fi/cm_strings.xml
@@ -1,22 +1,20 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
-<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
+<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string name="callStatsDetailTitle">Puheluiden lisätiedot</string>
<string name="call_stats">Puhelutiedot</string>
<string name="call_stats_refresh">Päivitä</string>
diff --git a/res/values-fr/cm_arrays.xml b/res/values-fr/cm_arrays.xml
index dd3604339..4fd67ce98 100644
--- a/res/values-fr/cm_arrays.xml
+++ b/res/values-fr/cm_arrays.xml
@@ -1,19 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string-array name="call_stats_duration">
<item><xliff:g id="seconds" example="2 secs">%3$s</xliff:g></item>
diff --git a/res/values-fr/cm_plurals.xml b/res/values-fr/cm_plurals.xml
index dd86ac1dc..6b272e52c 100644
--- a/res/values-fr/cm_plurals.xml
+++ b/res/values-fr/cm_plurals.xml
@@ -1,19 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<plurals name="hour">
<item quantity="one">1 h</item>
diff --git a/res/values-fr/cm_strings.xml b/res/values-fr/cm_strings.xml
index 93b694b67..7f67e256f 100644
--- a/res/values-fr/cm_strings.xml
+++ b/res/values-fr/cm_strings.xml
@@ -1,19 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string name="callStatsDetailTitle">Détails des statistiques d\'appels</string>
<string name="call_stats">Statistiques</string>
diff --git a/res/values-hu/cm_arrays.xml b/res/values-hu/cm_arrays.xml
index c07f9204a..4fd67ce98 100644
--- a/res/values-hu/cm_arrays.xml
+++ b/res/values-hu/cm_arrays.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string-array name="call_stats_duration">
<item><xliff:g id="seconds" example="2 secs">%3$s</xliff:g></item>
diff --git a/res/values-hu/cm_plurals.xml b/res/values-hu/cm_plurals.xml
index f599a5d90..35927457a 100644
--- a/res/values-hu/cm_plurals.xml
+++ b/res/values-hu/cm_plurals.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<plurals name="hour">
<item quantity="one">1 óra</item>
diff --git a/res/values-hu/cm_strings.xml b/res/values-hu/cm_strings.xml
index ab21a3d67..0960cbd02 100644
--- a/res/values-hu/cm_strings.xml
+++ b/res/values-hu/cm_strings.xml
@@ -1,19 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string name="callStatsDetailTitle">Részletek</string>
<string name="call_stats">Hívásinfó</string>
diff --git a/res/values-it/cm_arrays.xml b/res/values-it/cm_arrays.xml
index c07f9204a..4fd67ce98 100644
--- a/res/values-it/cm_arrays.xml
+++ b/res/values-it/cm_arrays.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string-array name="call_stats_duration">
<item><xliff:g id="seconds" example="2 secs">%3$s</xliff:g></item>
diff --git a/res/values-it/cm_plurals.xml b/res/values-it/cm_plurals.xml
index 426db0cf5..0e39367cf 100644
--- a/res/values-it/cm_plurals.xml
+++ b/res/values-it/cm_plurals.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<plurals name="hour">
<item quantity="one">1 ora</item>
diff --git a/res/values-it/cm_strings.xml b/res/values-it/cm_strings.xml
index ed94dad38..97ab90918 100644
--- a/res/values-it/cm_strings.xml
+++ b/res/values-it/cm_strings.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string name="callStatsDetailTitle">Dettagli chiamate</string>
<string name="call_stats">Statistiche</string>
diff --git a/res/values-nl/cm_arrays.xml b/res/values-nl/cm_arrays.xml
index dd3604339..4fd67ce98 100644
--- a/res/values-nl/cm_arrays.xml
+++ b/res/values-nl/cm_arrays.xml
@@ -1,19 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string-array name="call_stats_duration">
<item><xliff:g id="seconds" example="2 secs">%3$s</xliff:g></item>
diff --git a/res/values-nl/cm_plurals.xml b/res/values-nl/cm_plurals.xml
index d301ad0eb..9fe7d45c2 100644
--- a/res/values-nl/cm_plurals.xml
+++ b/res/values-nl/cm_plurals.xml
@@ -1,19 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<plurals name="hour">
<item quantity="one">1 uur</item>
diff --git a/res/values-nl/cm_strings.xml b/res/values-nl/cm_strings.xml
index 322983976..22259f336 100644
--- a/res/values-nl/cm_strings.xml
+++ b/res/values-nl/cm_strings.xml
@@ -1,22 +1,22 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string name="callStatsDetailTitle">Gespreksstatistiekdetails</string>
- <string name="call_stats">>Gespreksstatistieken</string>
+ <string name="call_stats">Gespreksstatistieken</string>
<string name="call_stats_refresh">Vernieuwen</string>
<string name="activity_title_call_stats">Gespreksstatistieken</string>
<string name="call_stats_nav_all">Alles</string>
diff --git a/res/values-pl/cm_arrays.xml b/res/values-pl/cm_arrays.xml
index dd3604339..4fd67ce98 100644
--- a/res/values-pl/cm_arrays.xml
+++ b/res/values-pl/cm_arrays.xml
@@ -1,19 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string-array name="call_stats_duration">
<item><xliff:g id="seconds" example="2 secs">%3$s</xliff:g></item>
diff --git a/res/values-pl/cm_plurals.xml b/res/values-pl/cm_plurals.xml
index 61e2730f7..819404811 100644
--- a/res/values-pl/cm_plurals.xml
+++ b/res/values-pl/cm_plurals.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<plurals name="hour">
<item quantity="one">1 godz.</item>
diff --git a/res/values-pl/cm_strings.xml b/res/values-pl/cm_strings.xml
index f836e8d06..da18c59b4 100644
--- a/res/values-pl/cm_strings.xml
+++ b/res/values-pl/cm_strings.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string name="callStatsDetailTitle">Szczegółowe statystyki połączeń</string>
<string name="call_stats">Statystyki połączeń</string>
diff --git a/res/values-pt/cm_plurals.xml b/res/values-pt/cm_plurals.xml
index 4ea795b82..b3843643d 100644
--- a/res/values-pt/cm_plurals.xml
+++ b/res/values-pt/cm_plurals.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<plurals name="hour">
<item quantity="one">1 hr</item>
@@ -28,7 +27,6 @@
<item quantity="one">1 seg</item>
<item quantity="other">%d segs</item>
</plurals>
-
<plurals name="call">
<item quantity="one">1 chamada</item>
<item quantity="other">%d chamadas</item>
diff --git a/res/values-pt/cm_strings.xml b/res/values-pt/cm_strings.xml
index 91df348d6..9026f4da5 100644
--- a/res/values-pt/cm_strings.xml
+++ b/res/values-pt/cm_strings.xml
@@ -1,5 +1,6 @@
<?xml version="1.0" encoding="utf-8"?>
-<!-- Copyright (C) 2013 The CyanogenMod Project
+<!--
+ Copyright (C) 2013 The CyanogenMod Project
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
@@ -22,12 +23,12 @@
<string name="call_stats_nav_incoming">Recebidas</string>
<string name="call_stats_nav_outgoing">Enviadas</string>
<string name="call_stats_nav_missed">Perdidas</string>
- <string name="call_stats_incoming">Recebidas: <xliff:g id="percent" xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">%d</xliff:g>%%</string>
- <string name="call_stats_outgoing">Enviadas: <xliff:g id="percent" xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">%d</xliff:g>%%</string>
+ <string name="call_stats_incoming">Recebidas: <xliff:g id="percent">%d</xliff:g>%%</string>
+ <string name="call_stats_outgoing">Enviadas: <xliff:g id="percent">%d</xliff:g>%%</string>
<string name="call_stats_missed">Perdidas</string>
- <string name="call_stats_missed_percent">Perdidas: <xliff:g id="percent" xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">%d</xliff:g>%%</string>
- <string name="call_stats_header_total">Total: <xliff:g id="call_count" xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">%s</xliff:g>, <xliff:g id="duration" xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">%s</xliff:g></string>
- <string name="call_stats_header_total_callsonly">Total: <xliff:g id="call_count" xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">%s</xliff:g></string>
+ <string name="call_stats_missed_percent">Perdidas: <xliff:g id="percent">%d</xliff:g>%%</string>
+ <string name="call_stats_header_total">Total: <xliff:g id="call_count">%s</xliff:g>, <xliff:g id="duration">%s</xliff:g></string>
+ <string name="call_stats_header_total_callsonly">Total: <xliff:g id="call_count">%s</xliff:g></string>
<string name="call_stats_filter_from">Data inicial</string>
<string name="call_stats_filter_to">Data final</string>
<string name="call_stats_filter_picker_title">Filtro por intervalo</string>
@@ -45,4 +46,4 @@
<string name="call_stats_sort_by_count">Ordenar por quantidade de chamadas</string>
<string name="menu_add_to_blacklist">Adicionar à lista de bloqueio</string>
<string name="toast_added_to_blacklist">%s adicionado à lista de bloqueio.</string>
-</resources> \ No newline at end of file
+</resources>
diff --git a/res/values-ru/cm_arrays.xml b/res/values-ru/cm_arrays.xml
index c07f9204a..4fd67ce98 100644
--- a/res/values-ru/cm_arrays.xml
+++ b/res/values-ru/cm_arrays.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string-array name="call_stats_duration">
<item><xliff:g id="seconds" example="2 secs">%3$s</xliff:g></item>
diff --git a/res/values-ru/cm_plurals.xml b/res/values-ru/cm_plurals.xml
index d878a579d..f675383ac 100644
--- a/res/values-ru/cm_plurals.xml
+++ b/res/values-ru/cm_plurals.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<plurals name="hour">
<item quantity="other">%d ч.</item>
diff --git a/res/values-ru/cm_strings.xml b/res/values-ru/cm_strings.xml
index 5e04962a7..e4fbad2cc 100644
--- a/res/values-ru/cm_strings.xml
+++ b/res/values-ru/cm_strings.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string name="callStatsDetailTitle">Статистика звонков</string>
<string name="call_stats">Статистика звонков</string>
diff --git a/res/values-sk/cm_plurals.xml b/res/values-sk/cm_plurals.xml
index 39d03e479..69174ca9b 100644
--- a/res/values-sk/cm_plurals.xml
+++ b/res/values-sk/cm_plurals.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<plurals name="hour">
<item quantity="one">1 hodina</item>
@@ -31,7 +30,6 @@
<item quantity="few">%d sekundy</item>
<item quantity="other">%d sekúnd</item>
</plurals>
-
<plurals name="call">
<item quantity="one">1 hovor</item>
<item quantity="few">%d hovory</item>
diff --git a/res/values-sk/cm_strings.xml b/res/values-sk/cm_strings.xml
index 85da33e59..626cc976f 100644
--- a/res/values-sk/cm_strings.xml
+++ b/res/values-sk/cm_strings.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string name="callStatsDetailTitle">Podrobná štatistika hovorov</string>
<string name="call_stats">Štatistiky hovorov</string>
diff --git a/res/values-sv/cm_plurals.xml b/res/values-sv/cm_plurals.xml
index 6071d1e55..a668c0d85 100644
--- a/res/values-sv/cm_plurals.xml
+++ b/res/values-sv/cm_plurals.xml
@@ -1,19 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<plurals name="hour">
<item quantity="one">1 h</item>
diff --git a/res/values-sv/cm_strings.xml b/res/values-sv/cm_strings.xml
index 4d692777b..601385deb 100644
--- a/res/values-sv/cm_strings.xml
+++ b/res/values-sv/cm_strings.xml
@@ -1,19 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string name="callStatsDetailTitle">Detaljer för samtalsstatistik</string>
<string name="call_stats">Samtalsstatistik</string>
diff --git a/res/values-zh-rCN/cm_strings.xml b/res/values-zh-rCN/cm_strings.xml
new file mode 100644
index 000000000..12af405e5
--- /dev/null
+++ b/res/values-zh-rCN/cm_strings.xml
@@ -0,0 +1,49 @@
+<?xml version="1.0" encoding="utf-8"?>
+<!--
+ Copyright (C) 2013 The CyanogenMod Project
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
+<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
+ <string name="callStatsDetailTitle">通话统计数据详情</string>
+ <string name="call_stats">通话统计数据</string>
+ <string name="call_stats_refresh">刷新</string>
+ <string name="activity_title_call_stats">通话统计数据</string>
+ <string name="call_stats_nav_all">全部</string>
+ <string name="call_stats_nav_incoming">来电</string>
+ <string name="call_stats_nav_outgoing">呼出</string>
+ <string name="call_stats_nav_missed">未接</string>
+ <string name="call_stats_incoming">来电: <xliff:g id="percent">%d</xliff:g>%%</string>
+ <string name="call_stats_outgoing">呼出: <xliff:g id="percent">%d</xliff:g>%%</string>
+ <string name="call_stats_missed">未接</string>
+ <string name="call_stats_missed_percent">未接: <xliff:g id="percent">%d</xliff:g>%%</string>
+ <string name="call_stats_header_total">总计: <xliff:g id="call_count">%s</xliff:g>, <xliff:g id="duration">%s</xliff:g></string>
+ <string name="call_stats_header_total_callsonly">总计: <xliff:g id="call_count">%s</xliff:g></string>
+ <string name="call_stats_filter_from">开始日期</string>
+ <string name="call_stats_filter_to">结束日期</string>
+ <string name="call_stats_filter_picker_title">过滤范围</string>
+ <string name="date_quick_selection">快速选择</string>
+ <string name="date_qs_currentmonth">本月</string>
+ <string name="date_qs_currentquarter">本季度</string>
+ <string name="date_qs_currentyear">本年</string>
+ <string name="date_qs_lastweek">上周</string>
+ <string name="date_qs_lastmonth">上个月</string>
+ <string name="date_qs_lastquarter">上个季度</string>
+ <string name="date_qs_lastyear">去年</string>
+ <string name="call_stats_date_filter">调整时间范围</string>
+ <string name="call_stats_reset_filter">重置时间范围</string>
+ <string name="call_stats_sort_by_duration">以通话时间排序</string>
+ <string name="call_stats_sort_by_count">以通话次数排序</string>
+ <string name="menu_add_to_blacklist">添加到黑名单</string>
+ <string name="toast_added_to_blacklist">%s 已添加到黑名单.</string>
+</resources>
diff --git a/res/values/cm_arrays.xml b/res/values/cm_arrays.xml
index 99327d1a4..4a58561dd 100644
--- a/res/values/cm_arrays.xml
+++ b/res/values/cm_arrays.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<string-array name="call_stats_nav_items" translatable="false">
<item>@string/call_stats_nav_all</item>
diff --git a/res/values/cm_plurals.xml b/res/values/cm_plurals.xml
index 5aee00dc4..0c4b4d21a 100644
--- a/res/values/cm_plurals.xml
+++ b/res/values/cm_plurals.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<plurals name="hour">
<item quantity="one">1 hr</item>
diff --git a/res/values/cm_strings.xml b/res/values/cm_strings.xml
index e9ca582eb..f9bb364f7 100644
--- a/res/values/cm_strings.xml
+++ b/res/values/cm_strings.xml
@@ -1,20 +1,19 @@
<?xml version="1.0" encoding="utf-8"?>
<!--
- ~ Copyright (C) 2013 The CyanogenMod Project
- ~
- ~ Licensed under the Apache License, Version 2.0 (the "License");
- ~ you may not use this file except in compliance with the License.
- ~ You may obtain a copy of the License at
- ~
- ~ http://www.apache.org/licenses/LICENSE-2.0
- ~
- ~ Unless required by applicable law or agreed to in writing, software
- ~ distributed under the License is distributed on an "AS IS" BASIS,
- ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- ~ See the License for the specific language governing permissions and
- ~ limitations under the License
- -->
+ Copyright (C) 2013 The CyanogenMod Project
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+-->
<resources xmlns:xliff="urn:oasis:names:tc:xliff:document:1.2">
<!-- Title bar for call stat detail screen -->
diff --git a/src/com/android/dialer/calllog/CallLogFragment.java b/src/com/android/dialer/calllog/CallLogFragment.java
index 86a383aa9..6d523a140 100644
--- a/src/com/android/dialer/calllog/CallLogFragment.java
+++ b/src/com/android/dialer/calllog/CallLogFragment.java
@@ -519,9 +519,12 @@ public class CallLogFragment extends ListFragment
mAdapter.invalidateCache();
startCallsQuery();
startVoicemailStatusQuery();
- updateOnEntry();
mRefreshDataRequired = false;
+ } else {
+ // make adapter refresh, so call dates are updated
+ mAdapter.notifyDataSetChanged();
}
+ updateOnEntry();
}
/** Removes the missed call notifications. */
diff --git a/src/com/android/dialer/dialpad/DialpadFragment.java b/src/com/android/dialer/dialpad/DialpadFragment.java
index 5f70312ff..c913a7098 100644
--- a/src/com/android/dialer/dialpad/DialpadFragment.java
+++ b/src/com/android/dialer/dialpad/DialpadFragment.java
@@ -43,6 +43,7 @@ import android.provider.Contacts.Intents.Insert;
import android.provider.Contacts.People;
import android.provider.Contacts.Phones;
import android.provider.Contacts.PhonesColumns;
+import android.provider.ContactsContract;
import android.provider.Settings;
import android.telephony.PhoneNumberUtils;
import android.telephony.PhoneStateListener;
@@ -1745,10 +1746,12 @@ public class DialpadFragment extends Fragment
final SmartDialEntry entry = (SmartDialEntry) view.getTag();
if (entry == null) return false; // just in case.
mClearDigitsOnStop = true;
- // Show the phone number disambiguation dialog without using the primary
- // phone number so that the user can decide which number to call
- PhoneNumberInteraction.startInteractionForPhoneCall(
- (TransactionSafeActivity) getActivity(), entry.contactUri, false);
+ // Show quick contact dialog so the user can decide which number
+ // to call or perform other operations
+ Intent intent = ContactsContract.QuickContact.composeQuickContactsIntent(
+ getActivity(), view, entry.contactUri,
+ ContactsContract.QuickContact.MODE_LARGE, null);
+ startActivity(intent);
return true;
}
}